pub struct HoprCodecConfig {
pub outgoing_ticket_price: Option<Balance<WxHOPR>>,
pub min_incoming_ticket_price: Option<Balance<WxHOPR>>,
pub outgoing_win_prob: Option<WinningProbability>,
}Expand description
Configuration of HoprEncoder and HoprDecoder.
Fields
outgoing_ticket_price: Option<Balance<WxHOPR>>Optional price of outgoing tickets.
If not set (default), the network default will be used, which is the minimum allowed ticket price in the HOPR network.
min_incoming_ticket_price: Option<Balance<WxHOPR>>Optional minimum price of incoming tickets.
The value cannot be lower than the default outgoing ticket price times the node’s path position.
If not set (default), the network default outgoing ticket price times the node’s path position will be used.
outgoing_win_prob: Option<WinningProbability>Optional probability of winning an outgoing ticket.
If not set (default), the network default will be used, which is the minimum allowed winning probability in the HOPR network.